@@ -14,7 +14,7 @@ def get_test_account():
     )
     if created:
         user.save()
-        user.set_password('password')
+        user.set_password('azer')
         for group in Group.objects.all():
             user.groups.add(group)
         user.save()
