@@ -33,14 +33,14 @@ class GridInfoEntry(EntryBlock):
 
     def mock(self, *args, **kwargs):
         if 'theme' in kwargs:
-            file = self.mocker.SVG_ICON_LIGHT \
-                if kwargs['theme'] == constants.THEME_LIGHT else self.mocker.SVG_ICON_SPACE
+            file = self.SVG_ICON_LIGHT \
+                if kwargs['theme'] == constants.THEME_LIGHT else self.SVG_ICON_SPACE
         else:
-            file = self.mocker.SVG_ICON_SPACE
+            file = self.SVG_ICON_SPACE
         info = {
             'type': 'svg_info',
             'value': {
-                'file': self.mocker.file(file).id,
+                'file': self.file(file).id,
                 'title': "Lorem ipsum",
                 'text_hover': {
                     'value': "<h3>lorem ipsum dolor sit amet consectetur adipisicing elit sed do eiusmod</h3>"
