@@ -3,7 +3,12 @@ from wagtail.admin.edit_handlers import StreamFieldPanel, FieldPanel
 from wagtail.core.fields import StreamField
 from wagtail.snippets.blocks import SnippetChooserBlock
 from modelcluster.models import ClusterableModel
-from webspace.cms.blocks.common import ButtonBlock, LinkBlock, FormBlock
+from webspace.loader import get_class
+
+
+ButtonBlock = get_class('cms.blocks.common', 'ButtonBlock')
+LinkBlock = get_class('cms.blocks.common', 'LinkBlock')
+StreamCard = get_class('cms.blocks.entries', 'StreamCard')
 
 
 class ANavigation(ClusterableModel):
@@ -11,6 +16,7 @@ class ANavigation(ClusterableModel):
 
     footer = StreamField([
         ('menu', SnippetChooserBlock('cms.Menu', required=False)),
+        ('stream_card', StreamCard())
     ], blank=True, verbose_name="Footer items")
 
     header_menus = StreamField([
