@@ -152,20 +152,20 @@ const Aside = {
 
 const Lazy = {
   init: () => {
-    const io = new IntersectionObserver(entries => entries.forEach((entry) => {
-      if (entry.isIntersecting) {
-        const element = entry.target;
+    if ('loading' in HTMLImageElement.prototype) {
+      const elements = document.querySelectorAll('*[loading="lazy"]');
+      elements.forEach((element) => {
         if (element.id.startsWith('slide-')) {
-          // background
           element.style.backgroundImage = `url(${element.dataset.src})`;
         } else {
-          // classic
           element.src = element.dataset.src;
         }
-        io.unobserve(element);
-      }
-    }));
-    document.querySelectorAll('.lazy').forEach(element => io.observe(element));
+      });
+    } else {
+      const script = document.createElement('script');
+      script.src = 'https://cdnjs.cloudflare.com/ajax/libs/lazysizes/5.1.2/lazysizes.min.js';
+      document.body.appendChild(script);
+    }
   },
 };
 
@@ -283,8 +283,8 @@ const BgSlide = {
               resfresh();
             });
           }
+          io.unobserve(element);
         }
-        io.unobserve(element);
       }
     }));
     document.querySelectorAll('.bg-container').forEach(element => io.observe(element));
